It returns the same string, unaffected, for any gender. This marks the string for future translation, and records it as a missing translation with unknown locale.
gender
String gender(Gender gender) => recordMissingKey(this);