plural method

String plural(
  1. dynamic value, [
  2. Gender? gender
])

Translates a string where %d is replaced by the given number. It returns the same value provided, where %d is replaced by the given number. This marks the string for future translation, and records the given value as a key missing translation with unknown locale. The gender is ignored.

Implementation

String plural(value, [Gender? gender]) {
  recordMissingKey(this);
  return replaceAll("%d", value.toString());
}